Edit in Plunker

    <div id="implicit" ng-controller="MyController">
      <p>Let's try the notify service, that is implicitly injected into the controller...</p>
      <input ng-init="message='test'" ng-model="message">
      <button ng-click="callNotify(message);">NOTIFY</button>
      <p>(you have to click 3 times to see an alert)</p>
    </div>

    angular.module('myServiceModuleDI', []).
      factory('notify', function($window) {
        var msgs = [];
        return function(msg) {
          msgs.push(msg);
          if (msgs.length == 3) {
            $window.alert(msgs.join("\n"));
            msgs = [];
          }
        };
      }).
      controller('MyController', function($scope, notify) {
        $scope.callNotify = function(msg) {
          notify(msg);
        };
      });

age="js">

    it('should test service', function() {
      expect(element(by.id('simple')).element(by.model('message')).getAttribute('value'))
          .toEqual('test');
    });

y('integer', false); return undefined; } }); } }; }); var FLOAT_REGEXP = /^\-?\d+((\.|\,)\d+)?$/; app.directive('smartFloat', function() { return { require: 'ngModel', link: function(scope, elm, attrs, ctrl) { ctrl.$parsers.unshift(function(viewValue) { if (FLOAT_REGEXP.test(viewValue)) { ctrl.$setValidity('float', true); return parseFloat(viewValue.replace(',', '.')); } else { ctrl.$setValidity('float', false); return undefined; } }); } }; });
quot;selected" ng-transclude> </div>
invoice.inCurr"> <option ng-repeat="c in invoice.currencies">{{c}}</option> </select> </div> <div> <b>Total:</b> <span ng-repeat="c in invoice.currencies"> {{invoice.total(c) | currency:c}} </span> <button class="btn" ng-click="invoice.pay()">Pay</button> </div> </div>
;, function() { return function(scope, elm, attrs) { var browser = browsers[attrs.browser], input = angular.element('<input type="text" style="width: 400px">').val(browser.url()), delay; input.on('keypress keyup keydown', function() { if (!delay) { delay = setTimeout(fireUrlChange, 250); } }); browser.url = function(url) { return input.val(url); }; elm.append('Address: ').append(input); function fireUrlChange() { delay = null; browser.urlChange(input.val()); } }; }); }]); root.on('click', function(e) { e.stopPropagation(); }); } initEnv('html5'); initEnv('hashbang');